@@ -117,6 +117,8 @@ class LDAP(object):
         self.conn.unbind_s()
         res = []
         for rec in records:
+            if rec[0] is None:
+                continue
             newrec = {}
             for field in rec[1].keys():
                 try:
@@ -139,9 +141,9 @@ class LDAP(object):
         try:
             self.connect()
             user = "{0}@{1}".format(username, self.app.config['LDAP_DOMAIN'])
+            self.conn.set_option(ldap.OPT_REFERRALS, 0)
             self.conn.simple_bind_s(user, pwd.encode('utf8'))
             query = "sAMAccountName=%s" % username
-            session['username'] = username
             for user in self.ldap_query(query):
                 mu = dict(_id=user[self.app.config['LDAP_PROFILE_KEY']])
                 mu['username'] = user.get('sAMAccountName')
@@ -179,6 +181,7 @@ class LDAP(object):
                     flash(u"Login successful but not authorized.")
                     return False
 
+            session['username'] = username
             return True
 
         except ldap.LDAPError as e:
@@ -228,6 +231,9 @@ class LDAP(object):
 
 
 def login_required(f):
+    """
+    Decorator for views that require login.
+    """
     @wraps(f)
     def decorated(*args, **kwargs):
         if 'username' in session:
@@ -238,6 +244,9 @@ def login_required(f):
 
 
 def short_name(user):
+    """
+    Make short name
+    """
     fn = user.get('description', '').decode('utf8').split(' ')
     ln = user.get('sn', fn[0].encode('utf8')).decode('utf8')
     gn = user.get('givenName', '').decode('utf8')
